@@ -18,8 +18,21 @@ class Module(SettingsBase):
         if self.output:
             if "name" not in self.output:
                 self.output["name"] = self.__name__
+            self.output["instance"] = str(id(self))
             json.insert(0, self.output)
 
+    def on_click(self, button):
+        if button == 1: # Left mouse button
+            self.on_leftclick()
+        elif button == 3: # Right mouse button
+            self.on_rightclick()
+
+    def on_leftclick(self):
+        pass
+
+    def on_rightclick(self):
+        pass
+
     def __repr__(self):
         return self.__class__.__name__
 
@@ -44,6 +57,11 @@ class IntervalModule(Module):
             am.append(self)
             IntervalModule.managers[self.interval] = am
 
+    @classmethod
+    def _start(cls):
+        for manager in cls.managers.values():
+            manager.start()
+
     def __call__(self):
         self.run()
 
@@ -52,3 +70,7 @@ class IntervalModule(Module):
 
         Do not rely on this being called from the same thread at all times.
         If you need to always have the same thread context, subclass AsyncModule."""
+
+START_HOOKS = (
+    IntervalModule._start,
+)
